Authenticator class

Constructors

Authenticator({required List<String> scopes, required String clientId, required String authorizationEndpointUrl, required String tokenEndpointUrl, required String logoutEndpointUrl, required String callbackUrl, Duration? renewalMargin, LaunchMode? launchMode})

Properties

authorizationEndpoint Uri
final
authorizationEndpointUrl String
final
callbackUrl Uri
final
clientId String
final
credentials → Credentials?
no setter
hashCode int
The hash code for this object.
no setterinherited
httpClient → Client
final
launchMode → LaunchMode
final
logoutEndpoint Uri
final
logoutEndpointUrl String
final
randomGenerator Random
final
renewalMargin Duration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes List<String>
final
tokenEndpoint Uri
final
tokenEndpointUrl String
final

Methods

complete(Uri responseUrl) Future<Credentials?>
getStoredCredentials() Future<Credentials?>
getUpdatedCredentials() Future<(Credentials?, bool)>
hostDesktopRedirectServer({required int port, required FutureOr<void> callback(Uri), String? desktopHost}) → void
login({Map<String, String> extraParameters = const {}}) Future<void>
logout() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refresh(Credentials credentials) Future<Credentials?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited